% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pmdc.R
\name{pmdc}
\alias{pmdc}
\title{Partial Martingale Difference Correlation (pMDC)}
\usage{
pmdc(X, Y, Z)
}
\arguments{
\item{X}{A vector or matrix where rows represent samples and columns represent variables.}

\item{Y}{A vector or matrix where rows represent samples and columns represent variables.}

\item{Z}{A vector or matrix where rows represent samples and columns represent variables.}
}
\value{
Returns the squared partial martingale difference correlation of \code{Y} given \code{X}, adjusting for the dependence on \code{Z}.
}
\description{
\code{pmdd} measures conditional mean dependence of \code{Y} given \code{X}, adjusting for the dependence on \code{Z}.
}
\examples{
# Generate example data
set.seed(123)
n <- 50
x <- matrix(rnorm(n * 5), nrow = n)  # explanatory variables
y <- matrix(rnorm(n), nrow = n)      # response variable
z <- matrix(rnorm(n * 2), nrow = n)  # conditioning variables

# Compute partial MDD
pmdd(x, y, z)

}
\references{
Park, T., Shao, X., and Yao, S. (2015). Partial martingale difference correlation. \emph{Electronic Journal of Statistics}, \bold{9}(1), 1492-1517. \doi{10.1214/15-EJS1047}.
}
